@@ -80,7 +80,7 @@ class Api:
     The list of active block Id's
     """
     
-    return frozenset([c['Id'] for c in self.list_blocks()])
+    return [c['Id'] for c in self.list_blocks()]
 
   def version(self):
     
@@ -205,7 +205,7 @@ class Api:
     """
     
     # parse kwargs
-    kw.setdefault('rule', None)
+    kw.setdefault('rule', {})
     assert('type' in kw)
 
     options = {
@@ -330,6 +330,9 @@ class Api:
     if 'daemon' in resp and 'does not exist' in resp['daemon']:
       raise ValueError('Block "{}" Does not exist'.format(conn_id))
 
+    elif 'daemon' in resp and 'already exist' in resp['daemon']:
+      raise ValueError('Block "{}" Already exists'.format(conn_id))
+
     elif 'dameon' in resp:
       raise ValueError('Input is malformed.')
     
